pm4py.algo.discovery.inductive.variants package
===============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.inductive.variants.im
   pm4py.algo.discovery.inductive.variants.im_clean
   pm4py.algo.discovery.inductive.variants.im_d
   pm4py.algo.discovery.inductive.variants.im_f

Module contents
---------------

.. automodule:: pm4py.algo.discovery.inductive.variants
   :members:
   :undoc-members:
   :show-inheritance:
